@@ -8,17 +8,13 @@
 #' @param group_pop A numeric vector with the population of the group for every precinct.
 #' @param total_pop A numeric vector with the population for every precinct.
 #' @param ncores Number of cores to use for parallel computing. Default is 1.
-#' @param district_membership Deprecated, use plans. A matrix with one row
-#' for each precinct and one column for each map. Required.
-#' @param grouppop Deprecated, use group_pop. A numeric vector with the population of the group for every precinct.
-#' @param fullpop Deprecated, use total_pop. A numeric vector with the population for every precinct.
 #'
 #' @return matrix with percent for each district
 #'
 #' @export
 #' @concept analyze
 #'
-#' @examples 
+#' @examples
 #' data(fl25)
 #' data(fl25_enum)
 #'
@@ -28,22 +24,7 @@
 #'                     group_pop = fl25$BlackPop,
 #'                     total_pop = fl25$TotPop)
 #'
-redist.group.percent <- function(plans, group_pop, total_pop, ncores = 1,
-                                 district_membership, grouppop, fullpop) {
-
-    if (!missing(district_membership)) {
-        plans <- district_membership
-        .Deprecated(new = 'plans', old = 'district_membership')
-    }
-    if (!missing(grouppop)) {
-        group_pop <- grouppop
-        .Deprecated(new = 'group_pop', old = 'grouppop')
-    }
-    if (!missing(fullpop)) {
-        total_pop <- fullpop
-        .Deprecated(new = 'total_pop', old = 'fullpop')
-    }
-
+redist.group.percent <- function(plans, group_pop, total_pop, ncores = 1) {
 
     if (!any(class(total_pop) %in% c('numeric', 'integer')))
         stop('Please provide "total_pop" as a numeric vector.')
