@@ -684,23 +684,6 @@ ecutsAppend <- function(algout,ndata){
 #' algorithm to generate starting values. Default is 5000.
 #' @param verbose Whether to print initialization statement. Default is
 #' \code{TRUE}.
-#' @param adjobj Deprecated, use adj. An adjacency matrix, list, or object of class
-#' "SpatialPolygonsDataFrame."
-#' @param popvec Deprecated, use total_pop. A vector containing the populations of each geographic
-#' unit.
-#' @param initcds Deprecated, use init_plan. A vector containing the congressional district labels
-#' of each geographic unit. The default is \code{NULL}. If not provided, random
-#' and contiguous congressional district assignments will be generated using
-#' \code{redist.rsg}.
-#' @param popcons Deprecated, use pop_tol. The strength of the hard population
-#' constraint. \code{popcons} = 0.05 means that any proposed swap that
-#' brings a district more than 5\% away from population parity will be
-#' rejected. The default is \code{NULL}.
-#' @param grouppopvec Deprecated, use group_pop. A vector of populations for some sub-group of
-#' interest. The default is \code{NULL}.
-#' @param countymembership Deprecated, use counties. A vector of county membership assignments. The default is \code{NULL}.
-#' @param contiguitymap Use queens or rooks distance criteria for generating an
-#' adjacency list from a "SpatialPolygonsDataFrame" data type. Default is "rooks".
 #'
 #'
 #' @details This function allows users to simulate redistricting plans
@@ -767,53 +750,17 @@ ecutsAppend <- function(algout,ndata){
 #'                 init_plan = init_plan, nsims = 10000, savename = "test")
 #' }
 #' @export
-redist.mcmc.mpi <- function(adj,
-                            total_pop,  nsims, ndists = NA,
+redist.mcmc.mpi <- function(adj, total_pop, nsims, ndists = NA,
                             init_plan = NULL,
                             loopscompleted = 0, nloop = 1, nthin = 1,
-                            eprob = 0.05,
-                            lambda = 0,
-                            pop_tol = NA,
-                            group_pop = NA,
-                            areasvec = NA,
-                            counties = NA,
-                            borderlength_mat = NA,
+                            eprob = 0.05, lambda = 0,
+                            pop_tol = NA, group_pop = NA, areasvec = NA,
+                            counties = NA, borderlength_mat = NA,
                             ssdmat = NA, compactness_metric = "fryer-holden", rngseed = NA,
                             constraint = NA, constraintweights = NA,
-                            betaseq = "powerlaw",
-                            betaseqlength = 10, adjswaps = TRUE,
-                            freq = 100, savename = NA, maxiterrsg = 5000,
-                             verbose = FALSE,
-                            adjobj, popvec, initcds, popcons, grouppopvec, countymembership, contiguitymap){
-
-  if(!missing(adjobj)){
-    .Deprecated(new = 'adj', old = 'adjobj')
-    adj <- adjobj
-  }
-  if(!missing(popvec)){
-    .Deprecated(new = 'total_pop', old = 'popvec')
-    total_pop <- popvec
-  }
-  if(!missing(initcds)){
-    .Deprecated(new = 'init_plan', old = 'initcds')
-    init_plan <- initcds
-  }
-  if(!missing(popcons)){
-    .Deprecated(new = 'pop_tol', old = 'popcons')
-    pop_tol <- popcons
-  }
-  if(!missing(grouppopvec)){
-    .Deprecated(new = 'group_pop', old = grouppopvec)
-    group_pop <- grouppopvec
-  }
-  if(!missing(countymembership)){
-    .Deprecated(new = 'counties', old = 'countymembership')
-    counties <- countymembership
-  }
-
-  if(!missing(contiguitymap)){
-    .Deprecated(msg = 'contiguitymap has been deprecated. Rooks adjacency built with redist.adjacency().')
-  }
+                            betaseq = "powerlaw", betaseqlength = 10,
+                            adjswaps = TRUE, freq = 100, savename = NA,
+                            maxiterrsg = 5000, verbose = FALSE){
   contiguitymap <- 'rooks'
 
     ## Check if Rmpi library is installed
