@@ -1,7 +1,7 @@
 #' 'Flip' Markov Chain Monte Carlo Redistricting Simulation
 #'
 #' \code{redist_flip} provides a tidy interface to the methods in
-#' \code{\link{redist.mcmc}}.
+#' \code{\link{redist.flip}}.
 #'
 #' This function allows users to simulate redistricting plans
 #' using the Markov Chain Monte Carlo methods of Fifield et al. Several
@@ -11,12 +11,12 @@
 #' tempering functionality to improve the mixing of the Markov Chain.
 #'
 #' \code{redist_flip} allows for Gibbs constraints to be supplied via a list object
-#' passed to \code{constraints}. This is a change from the original \code{redist.mcmc}
+#' passed to \code{constraints}. This is a change from the original \code{redist.flip}
 #' behavior to allow for a more straightforward function call when used within a pipe.
-#' A key difference between \code{redist_flip} and \code{redist.mcmc} is that
+#' A key difference between \code{redist_flip} and \code{redist.flip} is that
 #' \code{redist_flip} uses a small compactness constraint by default, as this improves
 #' the realism of the maps greatly and also leads to large speed improvements.
-#' (One of the most time consuming aspects of the mcmc/flip backend is checking for
+#' (One of the most time consuming aspects of the flip MCMC backend is checking for
 #' district shattering, which is slowed down even further by non-compact districts.
 #' As such, it is recommended that all flip simulations use at least a minimal compactness
 #' constraint, even if you weaken it from the default settings.) The default is
@@ -35,7 +35,7 @@
 #' \code{constraints}. The following describes the constraints available. The general
 #' advice is to set weights in a way that gets between 20\% and 40\% acceptance
 #' on average, though more tuning advice is available in the vignette on using
-#' mcmc methods.Having too small of an acceptance rate indicates that the weights
+#' MCMC methods.Having too small of an acceptance rate indicates that the weights
 #' within \code{constraints} are too large and will impact sampling efficiency.
 #' If the Metropolis Hastings acceptance rate is too large, this may impact the
 #' target distribution, but may be fine for general exploration of possible maps.
@@ -69,15 +69,12 @@
 #'   * weight - the coefficient to put on the Gibbs constraint
 #' * \code{hinge} This uses the proportion of a group in a district and matches to the
 #' nearest target proportion, and then creates a penalty of
-#' \eqn{\sqrt{max(0, nearest.target - group.pct)}}. This is equivalent to the
-#' \code{vra-old} constraint in  \code{redist_smc}.
+#' \eqn{\sqrt{max(0, nearest.target - group.pct)}}.
 #'   * weight - the coefficient to put on the Gibbs constraint
 #'   * minorityprop - A numeric vector of minority proportions (between 0 and 1) which
 #'   districts should aim to have
 #' * \code{vra} This takes two target proportions of the presence of a minority group
 #' within a district. \eqn{(|target.min - group.pct||target.other - group.pct|)^{1.5})}
-#' This is equivalent to the \code{vra-old} constraint in
-#' \code{redist_smc}.
 #'   * weight - the coefficient to put on the Gibbs constraint
 #'   * target_min - the target minority percentage. Often, this is set to 0.55 to encourage
 #'   minority majority districts.
@@ -105,14 +102,12 @@
 #'   * weight - the coefficient to put on the Gibbs constraint
 #'
 #'
-#'
-#'
 #' @param map A \code{\link{redist_map}} object.
 #' @param nsims The number of samples to draw, not including warmup.
 #' @param warmup The number of warmup samples to discard.
 #' @param init_plan A vector containing the congressional district labels
 #' of each geographic unit. The default is \code{NULL}. If not provided,
-#' a random initial plan will be generated using \code{redist.smc}. You can also
+#' a random initial plan will be generated using \code{redist_smc}. You can also
 #' request to initialize using \code{redist.rsg} by supplying 'rsg', though this is
 #' not recommended behavior.
 #' @param pop_tol The strength of the hard population
@@ -169,7 +164,7 @@
 #' data(iowa)
 #' iowa_map <- redist_map(iowa, ndists = 4, existing_plan = cd_2010, total_pop = pop, pop_tol = 0.01)
 #' sims <- redist_flip(map = iowa_map, nsims = 100)
-#' 
+#'
 redist_flip <- function(map, nsims, warmup = 0, init_plan, pop_tol, constraints = list(),
                         nthin = 1, eprob = 0.05, lambda = 0, temper = FALSE,
                         betaseq = 'powerlaw', betaseqlength = 10, betaweights = NULL,
@@ -181,7 +176,7 @@ redist_flip <- function(map, nsims, warmup = 0, init_plan, pop_tol, constraints
 
     cat('\n', append = TRUE)
     cat(divider, append = TRUE)
-    cat('redist.mcmc(): Automated Redistricting Simulation Using
+    cat('redist.flip(): Automated Redistricting Simulation Using
          Markov Chain Monte Carlo\n\n', append = TRUE)
   }
   # process raw inputs
@@ -191,6 +186,11 @@ redist_flip <- function(map, nsims, warmup = 0, init_plan, pop_tol, constraints
   total_pop <- map[[attr(map, 'pop_col')]]
   ndists <- attr(map, 'ndists')
 
+  if (any(total_pop >= get_target(map)))
+      stop("Units ", which(total_pop >= get_target(map)),
+           " have population larger than the district target.\n",
+           "Redistricting impossible.")
+
   # process constraints
   pre_pre_proc <- process_flip_constr(constraints, nprec)
 
@@ -234,16 +234,12 @@ redist_flip <- function(map, nsims, warmup = 0, init_plan, pop_tol, constraints
       } else {
         counties_smc <- pre_pre_proc$counties + 1
       }
-      invisible(capture.output(init_plan <- redist.smc(
-        adj = adj,
-        total_pop = total_pop,
+      invisible(capture.output(init_plan <- redist_smc(map,
         nsims = 1,
-        ndists = ndists,
         counties = counties_smc,
-        pop_tol = pop_tol,
         silent = TRUE
       ), type = 'message'))
-      init_plan <- init_plan$plans - 1L
+      init_plan <- as.matrix(init_plan) - 1L
 
       if (is.null(init_name)) {
         init_name <- '<init>'
