@@ -25,16 +25,6 @@
 #' use a different set of start values and try again.  If it fails again,
 #' redist.rsg() returns an object of all NAs, indicating that use of more
 #' iterations may be advised.
-#' @param adj.list Deprecated, use adj. List of length N, where N is the number of precincts.
-#' Each list element is an integer vector indicating which precincts that precinct
-#' is adjacent to.  It is assumed that precinct numbers start at 0.
-#' @param population  Deprecated, use total_pop. numeric vector of list N, where N is the number of precincts.
-#' Each element lists the population total of the corresponding precinct, and is
-#' used to enforce population constraints.
-#' @param thresh Deprecated, use pop_tol. numeric, indicating how close district population targets have
-#' to be to the target population before algorithm converges.  thresh=0.05 for
-#' example means that all districts must be between 0.95 and 1.05 times the size
-#' of target.pop in population size.
 #'
 #' @return list, containing three objects containing the completed redistricting
 #' plan.
@@ -48,7 +38,7 @@
 #' }
 #'
 #' @author Benjamin Fifield, Department of Politics, Princeton University
-#' \email{benfifield@@gmail.com}, \url{https://benfifield.com/}
+#' \email{benfifield@@gmail.com}, \url{https://www.benfifield.com/}
 #'
 #' Michael Higgins, Department of Statistics, Kansas State University
 #' \email{mikehiggins@@k-state.edu},
@@ -76,26 +66,8 @@
 #'
 #' @concept simulate
 #' @export
-redist.rsg <- function(adj,
-                       total_pop,
-                       ndists,
-                       pop_tol,
-                       verbose = TRUE,
-                       maxiter=5000,
-                       adj.list, population, thresh){
-
-    if(!missing(adj.list)){
-        .Deprecated('adj',  old = 'adj.list')
-        adj <- adj.list
-    }
-    if(!missing(population)){
-        .Deprecated(new = 'total_pop', old = 'population')
-        total_pop <- population
-    }
-    if(!missing(thresh)){
-        .Deprecated(new = 'pop_tol', old = 'thresh')
-        pop_tol <- thresh
-    }
+redist.rsg <- function(adj, total_pop, ndists, pop_tol,
+                       verbose = TRUE, maxiter=5000) {
 
     if(verbose){
         divider <- c(paste(rep("=", 20), sep = "", collapse = ""), "\n")
